@@ -40,6 +40,7 @@ from The Open Group.
 #include "winconfig.h"
 #include "winmsg.h"
 #include "winmonitors.h"
+#include "winprefs.h"
 
 #ifdef XWIN_CLIPBOARD
 #include "winclipboard/winclipboard.h"
@@ -134,7 +135,7 @@ winInitializeScreenDefaults(void)
     defaultScreenInfo.fRootless = FALSE;
 #ifdef XWIN_MULTIWINDOW
     defaultScreenInfo.fMultiWindow = FALSE;
-    defaultScreenInfo.fCompositeWM = FALSE;
+    defaultScreenInfo.fCompositeWM = TRUE;
 #endif
 #if defined(XWIN_MULTIWINDOW) || defined(XWIN_MULTIWINDOWEXTWM)
     defaultScreenInfo.fMultiMonitorOverride = FALSE;
@@ -148,6 +149,13 @@ winInitializeScreenDefaults(void)
     defaultScreenInfo.fUseUnixKillKey = WIN_DEFAULT_UNIX_KILL;
     defaultScreenInfo.fIgnoreInput = FALSE;
     defaultScreenInfo.fExplicitScreen = FALSE;
+    defaultScreenInfo.hIcon = (HICON)
+        LoadImage(GetModuleHandle(NULL), MAKEINTRESOURCE(IDI_XWIN), IMAGE_ICON,
+                  GetSystemMetrics(SM_CXICON), GetSystemMetrics(SM_CYICON), 0);
+    defaultScreenInfo.hIconSm = (HICON)
+        LoadImage(GetModuleHandle(NULL), MAKEINTRESOURCE(IDI_XWIN), IMAGE_ICON,
+                  GetSystemMetrics(SM_CXSMICON), GetSystemMetrics(SM_CYSMICON),
+                  LR_DEFAULTSIZE);
 
     /* Note that the default screen has been initialized */
     fInitializedScreenDefaults = TRUE;
@@ -347,7 +355,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
                     ("ddxProcessArgument - screen - Invalid monitor number %d\n",
                      iMonitor);
                 UseMsg();
-                exit(0);
+                exit(1);
                 return 0;
             }
         }
@@ -396,7 +404,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
                             ("ddxProcessArgument - screen - Invalid monitor number %d\n",
                              iMonitor);
                         UseMsg();
-                        exit(0);
+                        exit(1);
                         return 0;
                     }
 
@@ -427,7 +435,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
                         ("ddxProcessArgument - screen - Invalid monitor number %d\n",
                          iMonitor);
                     UseMsg();
-                    exit(0);
+                    exit(1);
                     return 0;
                 }
 
@@ -599,6 +607,15 @@ ddxProcessArgument(int argc, char *argv[], int i)
     if (IS_OPTION("-compositewm")) {
         screenInfoPtr->fCompositeWM = TRUE;
 
+        /* Indicate that we have processed this argument */
+        return 1;
+    }
+    /*
+     * Look for the '-nocompositewm' argument
+     */
+    if (IS_OPTION("-nocompositewm")) {
+        screenInfoPtr->fCompositeWM = FALSE;
+
         /* Indicate that we have processed this argument */
         return 1;
     }
@@ -1095,6 +1112,30 @@ ddxProcessArgument(int argc, char *argv[], int i)
         return 1;
     }
 
+    if (IS_OPTION("-icon")) {
+        char *iconspec;
+        CHECK_ARGS(1);
+        iconspec = argv[++i];
+        screenInfoPtr->hIcon = LoadImageComma(iconspec, NULL,
+                                              GetSystemMetrics(SM_CXICON),
+                                              GetSystemMetrics(SM_CYICON),
+                                              0);
+        screenInfoPtr->hIconSm = LoadImageComma(iconspec, NULL,
+                                                GetSystemMetrics(SM_CXSMICON),
+                                                GetSystemMetrics(SM_CYSMICON),
+                                                LR_DEFAULTSIZE);
+        if ((screenInfoPtr->hIcon == NULL) ||
+            (screenInfoPtr->hIconSm == NULL)) {
+            ErrorF("ddxProcessArgument - icon - Invalid icon specification %s\n",
+                   iconspec);
+            exit(1);
+            return 0;
+        }
+
+        /* Indicate that we have processed the argument */
+        return 2;
+    }
+
     return 0;
 }
 
